@@ -3,6 +3,15 @@ from typing import TypeVar
 from maleo.types.string import ListOfStrs
 
 
+class Granularity(StrEnum):
+    STANDARD = "standard"
+    FULL = "full"
+
+    @classmethod
+    def choices(cls) -> ListOfStrs:
+        return [e.value for e in cls]
+
+
 class IdentifierType(StrEnum):
     ID = "id"
     UUID = "uuid"
