@@ -2,21 +2,17 @@ from pydantic import BaseModel, Field, model_validator
 from typing import Annotated, Generic, Literal, Self, TypeVar, overload
 from uuid import UUID
 from maleo.enums.status import (
-    DataStatus,
     ListOfDataStatuses,
-    SimpleDataStatusMixin,
     FULL_DATA_STATUSES,
 )
 from maleo.schemas.mixins.filter import convert as convert_filter
 from maleo.schemas.mixins.identity import (
     IdentifierMixin,
-    DataIdentifier,
     Ids,
     UUIDs,
     Names,
 )
 from maleo.schemas.mixins.sort import convert as convert_sort
-from maleo.schemas.mixins.timestamp import LifecycleTimestamp
 from maleo.schemas.operation.enums import ResourceOperationStatusUpdateType
 from maleo.schemas.parameter import (
     ReadSingleParameter as BaseReadSingleParameter,
@@ -37,6 +33,7 @@ from ..enums.parameter import (
     OptValueType,
 )
 from ..mixins.parameter import (
+    _validate_value_type_and_options,
     Group,
     Groups,
     IsMandatory,
@@ -53,15 +50,6 @@ from ..mixins.parameter import (
 from ..types.parameter import IdentifierValueType
 
 
-def _validate_value_type_and_options(value_type: ValueTypeEnum, options: OptListOfStrs):
-    if value_type is ValueTypeEnum.ENUM:
-        if options is None:
-            raise ValueError("Options can not be None if value type is enum")
-    else:
-        if options is not None:
-            raise ValueError("Options must be None if value type is not enum")
-
-
 class CreateParameter(
     Unit[OptStr],
     IsNullable[bool],
@@ -404,22 +392,3 @@ class DeleteSingleParameter(BaseDeleteSingleParameter[ParameterIdentifier]):
         return cls(
             identifier=ParameterIdentifier(type=identifier_type, value=identifier_value)
         )
-
-
-class ParameterSchema(
-    Unit[OptStr],
-    IsNullable[bool],
-    Options[OptListOfStrs],
-    ValueType[ValueTypeEnum],
-    Aliases[OptListOfStrs],
-    Name[str],
-    Group[ParameterGroup],
-    IsMandatory[bool],
-    SimpleDataStatusMixin[DataStatus],
-    LifecycleTimestamp,
-    DataIdentifier,
-):
-    @model_validator(mode="after")
-    def validate_value_type_and_options(self) -> Self:
-        _validate_value_type_and_options(self.value_type, self.options)
-        return self
