@@ -36,7 +36,7 @@ from maleo.types.string import OptStr, ListOfStrs
 from maleo.types.uuid import OptUUID, ListOfUUIDs, OptListOfUUIDs
 from ..enums.session import IdentifierType, SessionType as SessionTypeEnum
 from ..mixins.common import SessionId, SessionIds, ClientId, ClientIds, ParameterIds
-from ..mixins.session import SessionType, Name, SessionIdentifier
+from ..mixins.session import SessionType, SessionTypes, Name, SessionIdentifier
 from ..types.session import IdentifierValueType
 from .document import (
     GroupCSVDocument,
@@ -180,6 +180,7 @@ AnyCreateParameter = CreateGroupParameter | CreateIndividualParameter
 class ReadMultipleParameter(
     ReadPaginatedMultipleParameter,
     ClientIds[OptListOfUUIDs],
+    SessionTypes,
     UUIDOrganizationIds[OptListOfUUIDs],
     UUIDUserIds[OptListOfUUIDs],
     UUIDs[OptListOfUUIDs],
@@ -203,6 +204,7 @@ class ReadMultipleParameter(
             "statuses",
             "user_ids",
             "organization_ids",
+            "types",
             "client_ids",
             "search",
             "page",
